<?php 
/*
Шаблонизатор

Шаблонизатор ищет в папке проекта запрошенный html-файл, затем ищет в нём тег <template_name> с именем шаблона.
Далее происходит загрузка шаблона и заполнение его значениями тегов из запрошенного файла, загрузка указанных файлов и переменных.
После сформированный html-код передаётся PHP-обработчику, если такой найден и включена предварительная обработка.
Перед выводом на экран происходит повторное заполнение значениями тегов из запрошенного файла, загрузка указанных файлов и переменных.

*/


// IN_PRODUCTION -- признак готового проекта.
// Дальнейшие настройки могут использовать триггер IN_PRODUCTION. 
// FALSE -- признак работы в режиме разработки или на площадке разработчика
// TRUE -- рабочий режим
$IN_PRODUCTION = TRUE;

// Системная папка проекта.
// Эта папка содержит системные файлы шаблонизатора, которые не стоит редактировать
// Путь может быть абсолютным или относительным к этому файлу
$project_system = '_system_';

// Папка шаблонов проекта.
// Эта папка содержит шаблоны вашего проекта и обязательно должна содержать шаблон по-умолчанию с именем default_template
// Шаблон по-умолчанию будет загружен, если не указан иной или если тег <template_name> не найден
// Путь может быть абсолютным или относительным к этому файлу
$project_templates = '_templates_';

// Папка файлов проекта (корневая папка проекта).
// Эта папка содержит контент проекта и обязательно должна содержать контент по-умолчанию с именем default_html
// В файле контента по-умолчанию будет дополнительно осуществлён писк тех тегов, которые должны быть загружены, но не найдены в запрошенном файле
// Путь может быть абсолютным или относительным к этому файлу
$project_html = '_html_';

// Расширение рабочих файлов (исполняемых PHP-файлов на сервере)
$EXT = '.php';

// Расширение html-файлов с контентом страниц
$EXT_HTML = '.html';

// Имя файла по умолчанию (индексный файл)
$INDEX = 'index';

// Кодировка страниц (желательно использовать UTF-8)
$CHARSET = 'UTF-8';

// Контроль версии PHP и отказ работать при версии ниже чем задана. Рекомендуемые значения '5.2' или '4.3.2'
$PHP_VERSION_CHECK = '5.2';

// URL rewriting
// TRUE -- Если вы используете модуль mod_rewrite Apache для сокрытия запускающего фойла.
// FALSE -- Обычный режим, когда имя запускающего файла присутствует в URL, после него стоит знак вопроса и путь до вызываемой страницы.
// если URL rewriting включен, то по прежнему остается возможность обратиться к проекту через запускающий файл в URL
$URL_REWRITING = TRUE;

// Возможность использования исполняемых PHP-файлов предварительной обработки
// Если установить в TRUE, то перед сборкой HTML-кода для вывода на экран будет осуществлён поиск PHP файла с именем, совпадающим с запрошенным.
// Файл ищется рядом с запрошенным, затем в корне папки файлов проекта ищется файл default_php, затем в папке шаблонов ищется файл default_php.
// Первый же найденный файл подгружается как require_once и поиск останавливается. 
// При работе загруженного файла можно использовать массив $input, содержащий данные запрошенной страницы и шаблонов, а также массив $output, значения которого можно вставлять при выводе страницы.
// Если файл не найден происходит вывод html-кода
// При сбросе значения в FALSE предварительная обработка пропускается. 
// Если вы не планируете использовать предварительную обработку обязательно поставьте FALSE
$INCLUDE_PHP = FALSE;

// Признак разрешения кэширования страниц браузером пользователя
// FALSE -- отмена кэширования и вывод
//		Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0
// а также мета-тегов
//		<meta http-equiv="Cache-Control" content="no-store, no-cache, must-revalidate" />
//		<meta http-equiv="Pragma" content="no-cache" />
// TRUE -- рабочий режим, браузер может кэшировать страницы
$BROUSER_CACHE = $IN_PRODUCTION;










//
// НЕ РЕДАКТИРУЙТЕ НИЖЕ ЭТОЙ ЛИНИИ, ЕСЛИ ВЫ НЕ ПОНИМАЕТЕ ПОСЛЕДСТВИЙ ВАШИХ ДЕЙСТВИЙ.
// DO NOT EDIT BELOW THIS LINE, UNLESS YOU FULLY UNDERSTAND THE IMPLICATIONS.
// ----------------------------------------------------------------------------
//


define('IN_PRODUCTION', $IN_PRODUCTION);
define('PHP_VERSION_CHECK', $PHP_VERSION_CHECK);
define('INCLUDE_PHP', $INCLUDE_PHP);
define('EXT', $EXT);
define('EXT_HTML', $EXT_HTML);
define('INDEX', $INDEX);
define('CHARSET', $CHARSET);
define('BROUSER_CACHE', $BROUSER_CACHE);
define('URL_REWRITING', $URL_REWRITING);

// Define webroot
$project_pathinfo = pathinfo($_SERVER['PHP_SELF']);
$project_pathinfo = $project_pathinfo['dirname']; if ($project_pathinfo==='.' OR $project_pathinfo==DIRECTORY_SEPARATOR) $project_pathinfo = '';
define('WEBROOT', $project_pathinfo);
$project_pathinfo = pathinfo(__FILE__); 
// Define the front controller name and docroot
define('DOCROOT', $project_pathinfo['dirname'].DIRECTORY_SEPARATOR);
define('PROJECT_FILE',  $project_pathinfo['basename']);
// Define URI_PREFIX
if (strpos($_SERVER['REQUEST_URI'], $_SERVER['PHP_SELF'])===FALSE AND URL_REWRITING===TRUE)
{
	define('URI_PREFIX', WEBROOT);
} else {
	define('URI_PREFIX', $_SERVER['PHP_SELF'].'?');
}
// If the front controller is a symlink, change to the real docroot
is_link(PROJECT_FILE) and chdir(dirname(realpath(__FILE__)));
// If project folders are relative paths, make them absolute.
$project_system = file_exists($project_system) ? $project_system : DOCROOT.$project_system;
$project_templates = file_exists($project_templates) ? $project_templates : DOCROOT.$project_templates;
$project_html = file_exists($project_html) ? $project_html : DOCROOT.$project_html;
// Define system paths
define('SYSPATH', str_replace('\\', '/', realpath($project_system)).'/');
define('TEMPLPATH', str_replace('\\', '/', realpath($project_templates)).'/');
define('HTMLPATH', str_replace('\\', '/', realpath($project_html)).'/');

// Clean up
unset($IN_PRODUCTION, $EXT, $EXT_HTML, $INDEX, $CHARSET, $BROUSER_CACHE, $project_pathinfo, $project_system, $project_templates, $project_html);

if (file_exists(DOCROOT.'install'.EXT))
{
	// Load the installation tests
	include DOCROOT.'install'.EXT;
}
else
{
	// Initialize
	require SYSPATH.'bootstrap'.EXT;
}

/*
Copyright © 2009 Максим Зимин (MacMax) macmax.ru

Программа защищена законами и международными соглашениями о правах на интеллектуальную собственность. 
Данная программа лицензируется и распространяется БЕСПЛАТНО.
Если закон страны или области Вашего проживания запрещает Вам использовать программу, 
или программа не допускается к использованию в Вашей стране или Вашей области проживания, 
воздержитесь от использования программы.

Разрешается повторное распространение и использование как в виде исходника так и в двоичной форме, 
с модификациями или без, при соблюдении следующих условий:
	1.	При повторном распространении исходного кода должно оставаться указанное выше уведомление об авторском праве, 
			этот список условий и нижеследующий отказ от гарантий.
	2.	При повторном распространении двоичного кода должно воспроизводиться указанное выше уведомление об авторском праве, 
			этот список условий и нижеследующий отказ от гарантий в документации и/или в других материалах, 
			поставляемых при распространении.
	3.	Ни название сайта macmax.ru, ни имена его владельцев и держателей не могут быть использованы 
			в качестве поддержки или продвижения продуктов, основанных на этом программном обеспечении 
			без предварительного письменного разрешения.

ЭТА ПРОГРАММА ПРЕДОСТАВЛЕНА БЕСПЛАТНО ДЕРЖАТЕЛЯМИ АВТОРСКИХ ПРАВ И/ИЛИ ДРУГИМИ СТОРОНАМИ «КАК ОНА ЕСТЬ» 
БЕЗ КАКОГО-ЛИБО ВИДА ГАРАНТИЙ, ВЫРАЖЕННЫХ ЯВНО ИЛИ ПОДРАЗУМЕВАЕМЫХ, ВКЛЮЧАЯ, НО НЕ ОГРАНИЧИВАЯСЬ ИМИ, 
ПОДРАЗУМЕВАЕМЫЕ ГАРАНТИИ КОММЕРЧЕСКОЙ ЦЕННОСТИ И ПРИГОДНОСТИ ДЛЯ КОНКРЕТНОЙ ЦЕЛИ. 
НИ В КОЕМ СЛУЧАЕ, ЕСЛИ НЕ ТРЕБУЕТСЯ СООТВЕТСТВУЮЩИМ ЗАКОНОМ, ИЛИ НЕ УСТАНОВЛЕНО В УСТНОЙ ФОРМЕ, 
НИ ОДИН ДЕРЖАТЕЛЬ АВТОРСКИХ ПРАВ И НИ ОДНО ДРУГОЕ ЛИЦО, КОТОРОЕ МОЖЕТ ИЗМЕНЯТЬ И/ИЛИ ПОВТОРНО 
РАСПРОСТРАНЯТЬ ПРОГРАММУ, КАК БЫЛО РАЗРЕШЕНО ВЫШЕ, НЕ ОТВЕТСТВЕННЫ ПЕРЕД ВАМИ ЗА УБЫТКИ, 
ВКЛЮЧАЯ ЛЮБЫЕ ОБЩИЕ, СЛУЧАЙНЫЕ, СПЕЦИАЛЬНЫЕ ИЛИ ПОСЛЕДОВАВШИЕ УБЫТКИ, 
ПРОИСТЕКАЮЩИЕ ИЗ ИСПОЛЬЗОВАНИЯ ИЛИ НЕВОЗМОЖНОСТИ ИСПОЛЬЗОВАНИЯ ПРОГРАММЫ (ВКЛЮЧАЯ, 
НО НЕ ОГРАНИЧИВАЯСЬ ПОТЕРЕЙ ДАННЫХ, ИЛИ ДАННЫМИ, СТАВШИМИ НЕПРАВИЛЬНЫМИ, 
ИЛИ ПОТЕРЯМИ ПРИНЕСЁННЫМИ ИЗ-ЗА ВАС ИЛИ ТРЕТЬИХ ЛИЦ, ИЛИ ОТКАЗОМ ПРОГРАММЫ РАБОТАТЬ СОВМЕСТНО С ДРУГИМИ ПРОГРАММАМИ), 
ДАЖЕ ЕСЛИ ТАКОЙ ДЕРЖАТЕЛЬ ИЛИ ДРУГОЕ ЛИЦО БЫЛИ ИЗВЕЩЕНЫ О ВОЗМОЖНОСТИ ТАКИХ УБЫТКОВ.

*/

?>